@@ -296,7 +296,7 @@ class EmpiricalLearningModel:
         plt.show()
     
 
-def lccv(learner_inst, X, y, r=1.0, timeout=None, base=2, min_exp=6, MAX_ESTIMATE_MARGIN_FOR_FULL_EVALUATION=0.005, MAX_EVALUATIONS=10, target_anchor=.9, return_estimate_on_incomplete_runs=False, max_conf_interval_size_default=0.1, max_conf_interval_size_target=0.001, enforce_all_anchor_evaluations=False, seed=0, verbose=False, logger=None, min_evals_for_stability=3, use_train_curve=True,fix_train_test_folds=False, scoring="accuracy", visualize_lcs = False, exceptions = "message"):
+def lccv(learner_inst, X, y, r, timeout=None, base=2, min_exp=6, MAX_ESTIMATE_MARGIN_FOR_FULL_EVALUATION=0.005, MAX_EVALUATIONS=10, target_anchor=.9, return_estimate_on_incomplete_runs=False, max_conf_interval_size_default=0.1, max_conf_interval_size_target=0.001, enforce_all_anchor_evaluations=False, seed=0, verbose=False, logger=None, min_evals_for_stability=3, use_train_curve=True,fix_train_test_folds=False, scoring="accuracy", visualize_lcs = False, exceptions = "message"):
     """
     Evaluates a learner in an iterative fashion, using learning curves. The
     method builds upon the assumption that learning curves are convex. After
@@ -380,7 +380,7 @@ def lccv(learner_inst, X, y, r=1.0, timeout=None, base=2, min_exp=6, MAX_ESTIMAT
     ## MAIN LOOP
     while t <= T and elm.get_conf_interval_size_at_target(target_anchor) > max_conf_interval_size_target and len(elm.get_values_at_anchor(target_anchor)) < MAX_EVALUATIONS:
         
-        remaining_time = deadline - time.time() if deadline is not None else np.inf
+        remaining_time = deadline - time.time() - 0.1 if deadline is not None else np.inf
         if remaining_time < 1:
             logger.info("Timeout observed, stopping outer loop of LCCV")
             break
@@ -394,7 +394,7 @@ def lccv(learner_inst, X, y, r=1.0, timeout=None, base=2, min_exp=6, MAX_ESTIMAT
         ## INNER LOOP: acquire observations at anchor until stability is reached, or just a single one to repair convexity
         while repair_convexity or num_evaluations_at_t < min_evals_for_stability or (elm.get_conf_interval_size_at_target(s_t) > eps and num_evaluations_at_t < MAX_EVALUATIONS):
             
-            remaining_time = deadline - time.time() if deadline is not None else np.inf
+            remaining_time = deadline - time.time() - 0.1 if deadline is not None else np.inf
             if remaining_time < 1:
                 logger.info("Timeout observed, stopping inner loop of LCCV")
                 break
@@ -406,7 +406,7 @@ def lccv(learner_inst, X, y, r=1.0, timeout=None, base=2, min_exp=6, MAX_ESTIMAT
             try:
                 seed_used = 13 * (1 + seed) + num_evaluations_at_t
                 logger.debug(f"Adding point at size {s_t} with seed is {seed_used}. Remaining time: {remaining_time}s")
-                score_train, score_test = elm.compute_and_add_sample(s_t, seed_used, (deadline - time.time()) * 1000 if deadline is not None else None, verbose=verbose)
+                score_train, score_test = elm.compute_and_add_sample(s_t, seed_used, (deadline - time.time() - 0.1) * 1000 if deadline is not None else None, verbose=verbose)
                 num_evaluations_at_t += 1
                 logger.debug(f"Sample computed successfully. Observed performance was {np.round(score_train, 4)} (train) and {np.round(score_test, 4)} (test).")
             except func_timeout.FunctionTimedOut:
@@ -417,6 +417,8 @@ def lccv(learner_inst, X, y, r=1.0, timeout=None, base=2, min_exp=6, MAX_ESTIMAT
                 logger.info(f"Observed an exception at anchor {s_t}.\nRaising it to the outside and ignoring this candidate.\nThis is not necessarily a good strategy; depending on the exception, one should try the candidate again on the same or bigger data size, because this can be related to a too small sample size.\nThe exception was: {e}.")
                 if exceptions == "raise":
                     raise
+                score_train, score_test = np.nan, np.nan
+                num_evaluations_at_t += 1
             
             # check wheter a repair is needed
             if num_evaluations_at_t >= min_evals_for_stability and t < T and t > 2:                    
